======
Kernel
======


.. toctree::
   :maxdepth: 1
   :caption: Kernel objects

   kernel/cae_display_preferences
   kernel/input
   kernel/kernel
   kernel/messaging
   kernel/text_representation
   kernel/utility
